OC.L10N.register(
    "core",
    {
    "Please select a file." : "Выберыце файл.",
    "File is too big" : "Файл занадта вялікі",
    "The selected file is not an image." : "Выбраны файл не з'яўляецца відарысам.",
    "The selected file cannot be read." : "Не ўдалося прачытаць выбраны файл.",
    "The file was uploaded" : "Файл быў запампаваны.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Памер запампаванага файла перавышае значэнне дырэктывы upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Памер запампаванага файла перавышае значэнне дырэктывы MAX_FILE_SIZE у HTML форме",
    "The file was only partially uploaded" : "Файл быў запампаваны толькі часткова",
    "No file was uploaded" : "Ніводзін файл не быў запампаваны",
    "Missing a temporary folder" : "Адсутнічае часовая папка",
    "Could not write file to disk" : "Не ўдалося запісаць файл на дыск",
    "A PHP extension stopped the file upload" : "Пашырэнне PHP спыніла запампоўванне файла",
    "Invalid file provided" : "Прапанаваны файл некарэктны",
    "Unknown filetype" : "Невядомы тып файла",
    "An error occurred. Please contact your admin." : "Узнікла памылка. Звярніцеся да адміністратара.",
    "Invalid image" : "Памылковы відарыс",
    "State token does not match" : "Токен стану не супадае",
    "Could not complete login" : "Не атрымалася завяршыць уваход",
    "State token missing" : "Адсутнічае токен стану",
    "Your login token is invalid or has expired" : "Ваш токен для ўваходу памылковы або пратэрмінаваны",
    "Please use original client" : "Выкарыстоўвайце арыгінальны кліент",
    "Login" : "Лагін",
    "Unsupported email length (>255)" : "Даўжыня электроннага ліста не падтрымліваецца (>255)",
    "Password reset is disabled" : "Скід пароля адключаны",
    "Could not reset password because the token is expired" : "Не ўдалося скінуць пароль, бо тэрмін дзеяння токена скончыўся",
    "Could not reset password because the token is invalid" : "Не ўдалося скінуць пароль, бо токен памылковы",
    "Password is too long. Maximum allowed length is 469 characters." : "Пароль занадта доўгі. Максімальная дазволеная даўжыня — 469 сімвалаў.",
    "%s password reset" : "Скід пароля %s ",
    "Password reset" : "Скід пароля",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Націсніце кнопку ніжэй, каб скінуць пароль. Калі вы не запытвалі скід пароля, праігнаруйце гэты ліст.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Націсніце спасылку ніжэй, каб скінуць пароль. Калі вы не запытвалі скід пароля, праігнаруйце гэты ліст.",
    "Reset your password" : "Скінуць пароль",
    "Task not found" : "Заданне не знойдзена",
    "Internal error" : "Унутраная памылка",
    "Not found" : "Не знойдзена",
    "Node is locked" : "Вузел заблакаваны",
    "Bad request" : "Няправільны запыт",
    "Requested task type does not exist" : "Запытаны тып задання не існуе",
    "Necessary language model provider is not available" : "Неабходны пастаўшчык моўнай мадэлі недаступны",
    "No text to image provider is available" : "Няма даступных пастаўшчыкоў паслуг пераўтварэння тэксту ў відарыс",
    "Image not found" : "Відарыс не знойдзены",
    "No translation provider available" : "Няма даступных пастаўшчыкоў перакладу",
    "Could not detect language" : "Не ўдалося вызначыць мову",
    "Unable to translate" : "Немагчыма перакласці",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Nextcloud Server" : "Сервер Nextcloud",
    "Some of your link shares have been removed" : "Некаторыя з вашых абагуленых спасылак былі выдалены",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "З-за памылкі бяспекі нам давялося выдаліць некаторыя з вашых абагуленых спасылак. Больш падрабязную інфармацыю глядзіце па спасылцы.",
    "Learn more ↗" : "Больш падрабязна ↗",
    "Preparing update" : "Падрыхтоўка абнаўлення",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Скарыстайцеся абнаўленнем праз камандны радок, бо абнаўленне праз браўзер адключана ў вашым config.php.",
    "Turned on maintenance mode" : "Уключаны рэжым тэхнічнага абслугоўвання",
    "Turned off maintenance mode" : "Выключаны рэжым тэхнічнага абслугоўвання",
    "Maintenance mode is kept active" : "Рэжым тэхнічнага абслугоўвання застаецца актыўным",
    "Updating database schema" : "Абнаўленне схемы базы даных",
    "Updated database" : "Абноўлена база даных",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Праверка магчымасці абнаўлення схемы базы даных для %s (гэта можа заняць шмат часу ў залежнасці ад памеру базы даных)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" абноўлена да %2$s",
    "Reset log level" : "Скінуць узровень вядзення журнала",
    "Starting code integrity check" : "Запуск праверкі цэласнасці кода",
    "Finished code integrity check" : "Праверка цэласнасці кода завершана",
    "%s (incompatible)" : "%s (несумяшчальная)",
    "The following apps have been disabled: %s" : "Наступныя праграмы былі адключаны: %s",
    "Already up to date" : "Няма абнаўленняў",
    "Windows Command Script" : "Скрыпт каманднага радка Windows",
    "Electronic book document" : "Дакумент электроннай кнігі",
    "TrueType Font Collection" : "Калекцыя шрыфтоў TrueType",
    "Web Open Font Format" : "Фармат шрыфта Web Open",
    "GPX geographic data" : "Геаграфічныя дадыя GPX",
    "Gzip archive" : "Архіў Gzip",
    "Adobe Illustrator document" : "Дакумент Adobe Illustrator",
    "Java source code" : "Зыходны код Java",
    "JavaScript source code" : "Зыходны код JavaScript",
    "JSON document" : "Дакумент JSON",
    "Microsoft Access database" : "База даных Microsoft Access",
    "Microsoft OneNote document" : "Дакумент Microsoft OneNote",
    "Microsoft Word document" : "Дакумент Microsoft Word",
    "Unknown" : "Невядомы",
    "PDF document" : "Дакумент PDF",
    "PostScript document" : "Дакумент PostScript",
    "RSS summary" : "Зводка RSS",
    "Android package" : "Пакет Android",
    "KML geographic data" : "Геаграфічныя даныя KML",
    "KML geographic compressed data" : "Геаграфічныя сціснутыя даныя KML",
    "Lotus Word Pro document" : "Дакумент Lotus Word Pro",
    "Excel spreadsheet" : "Табліца Excel",
    "Excel add-in" : "Надбудова Excel",
    "Excel 2007 binary spreadsheet" : "Табліца Excel 2007 (у двайковым фармаце)",
    "Excel spreadsheet template" : "Шаблон табліцы Excel",
    "Outlook Message" : "Паведамленне Outlook",
    "PowerPoint presentation" : "Прэзентацыя PowerPoint",
    "PowerPoint add-in" : "Надбудова PowerPoint",
    "PowerPoint presentation template" : "Шаблон прэзентацыі PowerPoint",
    "Word document" : "Дакумент Word",
    "ODF formula" : "Формула ODF",
    "ODG drawing" : "Рысунак ODG",
    "ODG drawing (Flat XML)" : "Рысунак ODG (Плоскі XML)",
    "ODG template" : "Шаблон ODG",
    "ODP presentation" : "Прэзентацыя ODP",
    "ODP presentation (Flat XML)" : "Прэзентацыя ODP (Плоскі XML)",
    "ODP template" : "Шаблон ODP",
    "ODS spreadsheet" : "Табліца ODS",
    "ODS spreadsheet (Flat XML)" : "Табліца ODS (Плоскі XML)",
    "ODS template" : "Шаблон ODS",
    "ODT document" : "Дакумент ODT",
    "ODT document (Flat XML)" : "Дакумент ODT (Плоскі XML)",
    "ODT template" : "Шаблон ODT",
    "PowerPoint 2007 presentation" : "Прэзентацыя PowerPoint 2007",
    "PowerPoint 2007 show" : "Паказ powerpoint 2007",
    "PowerPoint 2007 presentation template" : "Шаблон прэзентацыі PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Табліца Excel 2007",
    "Excel 2007 spreadsheet template" : "Шаблон табліцы Excel 2007",
    "Word 2007 document" : "Дакумент Word 2007",
    "Word 2007 document template" : "Шаблон дакумента Word 2007",
    "Microsoft Visio document" : "Дакумент Microsoft Visio",
    "WordPerfect document" : "Дакумент WordPerfect",
    "7-zip archive" : "Архіў 7-zip",
    "Blender scene" : "Сцэна Blender",
    "Bzip2 archive" : "Архіў Bzip2",
    "Debian package" : "Пакет Debian",
    "FictionBook document" : "Дакумент FictionBook",
    "Unknown font" : "Невядомы шрыфт",
    "Krita document" : "Дакумент Krita",
    "Mobipocket e-book" : "Электронная кніга Mobipocket",
    "Windows Installer package" : "Пакет Windows Installer",
    "Perl script" : "Скрыпт Perl",
    "PHP script" : "Скрыпт PHP",
    "Tar archive" : "Архіў Tar",
    "XML document" : "Дакумент XML",
    "YAML document" : "Дакумент YAML",
    "Zip archive" : "Архіў Zip",
    "Zstandard archive" : "Архіў Zstandard",
    "AAC audio" : "Аўдыя AAC",
    "FLAC audio" : "Аўдыя FLAC",
    "MPEG-4 audio" : "Аўдыя MPEG-4",
    "MP3 audio" : "Аўдыя MP3",
    "Ogg audio" : "Аўдыя Ogg",
    "RIFF/WAVe standard Audio" : "Аўдыя ў стандарце RIFF/WAVe",
    "WebM audio" : "Аўдыя WebM",
    "MP3 ShoutCast playlist" : "Плэй-ліст MP3 ShoutCast",
    "Windows BMP image" : "Відарыс Windows BMP",
    "Better Portable Graphics image" : "Відарыс Better Portable Graphics",
    "EMF image" : "Відарыс EMF",
    "GIF image" : "Відарыс GIF",
    "HEIC image" : "Відарыс HEIC",
    "HEIF image" : "Відарыс HEIF",
    "JPEG-2000 JP2 image" : "Відарыс JPEG-2000 JP2",
    "JPEG image" : "Відарыс JPEG",
    "PNG image" : "Відарыс PNG",
    "SVG image" : "Відарыс SVG",
    "Truevision Targa image" : "Відарыс Truevision Targa",
    "TIFF image" : "Відарыс TIFF",
    "WebP image" : "Відарыс WebP",
    "Digital raw image" : "Лічбавы неапрацаваны відарыс",
    "Windows Icon" : "Значок Windows",
    "Email message" : "Паведамленне па электроннай пошце",
    "VCS/ICS calendar" : "Каляндар VCS/ICS",
    "CSS stylesheet" : "Табліца стыляў CSS",
    "CSV document" : "Дакумент CSV",
    "HTML document" : "Дакумент HTML",
    "Markdown document" : "Дакумент Markdown",
    "Org-mode file" : "Файл Org-mode",
    "Plain text document" : "Тэкставы дакумент",
    "Rich Text document" : "Дакумент Rich Text",
    "Electronic business card" : "Электронная візітная картка",
    "C++ source code" : "Зыходны код C++",
    "LDIF address book" : "Адрасная кніга LDIF",
    "NFO document" : "Дакумент NFO",
    "PHP source" : "Зыходны код PHP",
    "Python script" : "Скрыпт Python",
    "ReStructuredText document" : "Дакумент ReStructuredText",
    "3GPP multimedia file" : "Мультымедыйны файл 3GPP",
    "MPEG video" : "Відэа MPEG",
    "DV video" : "Відэа DV",
    "MPEG-2 transport stream" : "Транспартны паток MPEG-2",
    "MPEG-4 video" : "Відэа MPEG-4",
    "Ogg video" : "Відэа Ogg",
    "QuickTime video" : "Відэа QuickTime",
    "WebM video" : "Відэа WebM",
    "Flash video" : "Відэа Flash",
    "Matroska video" : "Відэа Matroska",
    "Windows Media video" : "Відэа Windows Media",
    "AVI video" : "Відэа AVI",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Абнаўленне яшчэ ідзе. У некаторых асяроддзях, калі пакінуць гэтую старонку, працэс можа быць перапынены.",
    "Update to {version}" : "Абнавіць да {version}",
    "An error occurred." : "Узнікла памылка.",
    "Please reload the page." : "Перазагрузіце старонку.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Абнаўленне было няўдалым. Дадатковая інфармацыя – у прысвечаным гэтаму пытанню паведамленні на <a href=\"{url}\">нашым форуме</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Абнаўленне было няўдалым. Паведаміце пра гэту праблему <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">супольнасці Nextcloud</a>.",
    "Done" : "Гатова",
    "Applications menu" : "Меню праграм",
    "Apps" : "Праграмы",
    "More apps" : "Болей праграм",
    "_{count} notification_::_{count} notifications_" : ["{count} апавяшчэнне","{count} апавяшчэнні","{count} апавяшчэнняў","{count} апавяшчэнняў"],
    "No" : "Не",
    "Yes" : "Так",
    "App password" : "Пароль праграмы",
    "Grant access" : "Дазволіць доступ",
    "The remote URL must include the user." : "Аддалены URL-адрас павінен уключаць карыстальніка.",
    "Invalid remote URL." : "Памылковы аддалены URL.",
    "Failed to add the public link to your Nextcloud" : "Не ўдалося дадаць публічную спасылку ў ваш Nextcloud",
    "Federated user" : "Федэратыўны карыстальнік",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Direct link copied" : "Прамая спасылка скапіявана",
    "Please copy the link manually:" : "Скапіюйце спасылку ўручную:",
    "Custom date range" : "Карыстальніцкі дыяпазон дат",
    "Pick start date" : "Выберыце дату пачатку",
    "Pick end date" : "Выберыце дату заканчэння",
    "Search in date range" : "Пошук у дыяпазоне дат",
    "Search in current app" : "Пошук у бягучай праграме",
    "Clear search" : "Ачысціць пошук",
    "Search everywhere" : "Шукаць усюды",
    "Searching …" : "Пошук …",
    "Start typing to search" : "Пачніце ўводзіць тэкст для пошуку",
    "Minimum search length is {minSearchLength} characters" : "Мінімальная даўжыня радка для пошуку складае {minSearchLength} сімвалаў",
    "No matching results" : "Няма адпаведных вынікаў",
    "Today" : "Сёння",
    "Last 7 days" : "Апошнія 7 дзён",
    "Last 30 days" : "Апошнія 30 дзён",
    "This year" : "Гэты год",
    "Last year" : "Мінулы год",
    "Between {startDate} and {endDate}" : "Паміж {startDate} і {endDate}",
    "Unified search" : "Уніфікаваны пошук",
    "Search apps, files, tags, messages" : "Пошук праграм, файлаў, тэгаў, паведамленняў",
    "Places" : "Месцы",
    "Date" : "Дата",
    "Search people" : "Пошук людзей",
    "People" : "Людзі",
    "Results" : "Вынікі",
    "Load more results" : "Загрузіць больш вынікаў",
    "Search in" : "Пошук у",
    "Log in" : "Увайсці",
    "Logging in …" : "Уваход …",
    "Log in to {productName}" : "Увайсці ў {productName}",
    "Wrong login or password." : "Няправільны лагін або пароль.",
    "This account is disabled" : "Гэты ўліковы запіс адключаны.",
    "Account name or email" : "Імя ўліковага запісу або email",
    "Account name" : "Імя ўліковага запісу",
    "Server side authentication failed!" : "Памылка аўтэнтыфікацыі на баку сервера!",
    "Please contact your administrator." : "Звярніцеся да адміністратара.",
    "Session error" : "Памылка сеанса",
    "It appears your session token has expired, please refresh the page and try again." : "Здаецца, тэрмін дзеяння токена сеанса скончыўся. Абнавіце старонку і паспрабуйце яшчэ раз.",
    "An internal error occurred." : "Узнікла ўнутраная памылка.",
    "Please try again or contact your administrator." : "Паспрабуйце яшчэ раз або звярніцеся да адміністратара.",
    "Password" : "Пароль",
    "Remember me" : "Запомніць мяне",
    "Log in with a device" : "Увайсці з дапамогай прылады",
    "Login or email" : "Лагін або электронная пошта",
    "Your connection is not secure" : "Ваша злучэнне не з'яўляецца бяспечным",
    "Browser not supported" : "Браўзер не падтрымліваецца",
    "Reset password" : "Скінуць пароль",
    "Back to login" : "Назад да формы ўваходу",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Калі гэты ўліковы запіс існуе, на яго адрас электроннай пошты было адпраўлена паведамленне для скіду пароля. Калі вы яго не атрымалі, спраўдзіце адрас электроннай пошты і/або лагін, праверце папку са спамам або звярніцеся па дапамогу да адміністратара.",
    "Couldn't send reset email. Please contact your administrator." : "Не ўдалося адправіць ліст для скіду. Звярніцеся да адміністратара.",
    "Password cannot be changed. Please contact your administrator." : "Немагчыма змяніць пароль. Звярніцеся да адміністратара.",
    "New password" : "Новы пароль",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Вашы файлы зашыфраваны. Пасля скіду пароля вы не зможаце аднавіць свае даныя. Калі вы не ведаеце, што рабіць, звярніцеся да адміністратара, перш чым працягнуць. Вы сапраўды хочаце працягнуць?",
    "I know what I'm doing" : "Я ведаю, што раблю",
    "Resetting password" : "Скід пароля",
    "Schedule work & meetings, synced with all your devices." : "Плануйце працу і сустрэчы, сінхранізуючы іх паміж усімі вашымі прыладамі.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Трымайце калег і сяброў у адным месцы, не раскрываючы іх асабістую інфармацыю.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Простая праграма электроннай пошты, добра інтэграваная з Файламі, Кантактамі і Календаром.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чаты, відэавыклікі, дэманстрацыя экрана, анлайн-сустрэчы і вэб-канферэнцыі — у вашым браўзеры і з дапамогай мабільных праграм.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Супольныя дакументы, электронныя табліцы і прэзентацыі, створаныя ў Collabora Online.",
    "Recommended apps" : "Рэкамендаваныя праграмы",
    "Loading apps …" : "Загрузка праграм …",
    "Could not fetch list of apps from the App Store." : "Не ўдалося атрымаць спіс праграм з App Store.",
    "App download or installation failed" : "Не ўдалося спампаваць або ўсталяваць праграму",
    "Cannot install this app because it is not compatible" : "Немагчыма ўсталяваць гэту праграму, бо яна несумяшчальная",
    "Cannot install this app" : "Немагчыма ўсталяваць гэту праграму",
    "Skip" : "Прапусціць",
    "Installing apps …" : "Усталяванне праграм …",
    "Install recommended apps" : "Усталяваць рэкамендаваныя праграмы",
    "Online" : "У сетцы",
    "Away" : "Адышоў",
    "Busy" : "Заняты",
    "Do not disturb" : "Не турбаваць",
    "Mute all notifications" : "Адключыць усе апавяшчэнні",
    "Invisible" : "Нябачны",
    "Appear offline" : "Паказваць \"Па-за сеткай\"",
    "Avatar of {displayName}" : "Аватар карыстальніка {displayName}",
    "Settings menu" : "Меню налад",
    "Loading your contacts …" : "Загрузка вашых кантактаў …",
    "Looking for {term} …" : "Пошук {term} …",
    "Search contacts" : "Пошук кантактаў",
    "Reset search" : "Скінуць пошук",
    "Search contacts …" : "Пошук кантактаў …",
    "Could not load your contacts" : "Не ўдалося загрузіць вашы кантакты",
    "No contacts found" : "Кантакты не знойдзены",
    "Show all contacts" : "Паказаць усе кантакты",
    "Install the Contacts app" : "Усталяваць праграму \"Кантакты\"",
    "Search" : "Пошук",
    "No results for {query}" : "Няма вынікаў для {query}",
    "Press Enter to start searching" : "Націсніце Enter, каб пачаць пошук",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Увядзіце хаця б {minSearchLength} сімвал для пошуку","Увядзіце хаця б {minSearchLength} сімвалы для пошуку","Увядзіце хаця б {minSearchLength} сімвалаў для пошуку","Увядзіце хаця б {minSearchLength} сімвалаў для пошуку"],
    "An error occurred while searching for {type}" : "Падчас пошуку {type} адбылася памылка",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Пошук пачынаецца, як толькі вы пачынаеце ўводзіць тэкст, і вынікаў можна дасягнуць з дапамогай клавіш са стрэлкамі",
    "Search for {name} only" : "Шукаць толькі {name}",
    "Loading more results …" : "Загрузка дадатковых вынікаў …",
    "Forgot password?" : "Забылі пароль?",
    "Back to login form" : "Назад да формы ўваходу",
    "Back" : "Назад",
    "Login form is disabled." : "Форма ўваходу адключана.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Форма ўваходу ў Nextcloud адключана. Скарыстайцеся іншым варыянтам уваходу, калі ён даступны, або звярніцеся да адміністратара.",
    "Security warning" : "Папярэджанне бяспекі",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Калі вы не спрабуеце наладзіць новую прыладу або праграму, значыць, хтосьці спрабуе падмануць вас, каб атрымаць доступ да вашых даных. У гэтым выпадку не працягвайце і звярніцеся да сістэмнага адміністратара.",
    "You can close this window." : "Вы можаце закрыць гэта акно.",
    "Account access" : "Доступ да ўліковага запісу",
    "More actions" : "Больш дзеянняў",
    "User menu" : "Меню карыстальніка",
    "Set public name" : "Задаць публічнае імя",
    "Change public name" : "Змяніць публічнае імя",
    "The password is wrong or expired. Please try again or request a new one." : "Пароль няправільны або скончыўся тэрмін яго дзеяння. Паспрабуйце яшчэ раз або запытайце новы.",
    "Submit" : "Адправіць",
    "Please type in your email address to request a temporary password" : "Увядзіце свой адрас электроннай пошты, каб запытаць часовы пароль",
    "Password sent!" : "Пароль адпраўлены!",
    "Email address" : "Адрас электроннай пошты",
    "Request password" : "Запытаць пароль",
    "Password is too weak" : "Пароль занадта слабы",
    "Password is weak" : "Пароль слабы",
    "Password is average" : "Пароль абы-які",
    "Password is strong" : "Пароль надзейны",
    "Password is very strong" : "Пароль вельмі надзейны",
    "Password is extremely strong" : "Пароль надзвычай надзейны",
    "Unknown password strength" : "Невядомая надзейнасць пароля",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш каталог даных і файлы, верагодна, даступныя з Інтэрнэту, таму што файл <code>.htaccess</code> не працуе.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Каб даведацца, як правільна наладзіць сервер, {linkStart}глядзіце дакументацыю{linkEnd}",
    "Autoconfig file detected" : "Выяўлены файл аўтаканфігурацыі",
    "Create administration account" : "Стварыце ўліковы запіс адміністратара",
    "Administration account name" : "Імя ўліковага запісу адміністратара",
    "Administration account password" : "Пароль уліковага запісу адміністратара",
    "Storage & database" : "Сховішча і база даных",
    "Data folder" : "Папка з данымі",
    "Database configuration" : "Канфігурацыя базы даных",
    "Database type" : "Тып базы даных",
    "Only {firstAndOnlyDatabase} is available." : "Даступна толькі {firstAndOnlyDatabase}.",
    "Install and activate additional PHP modules to choose other database types." : "Усталюйце і актывуйце дадатковыя модулі PHP, каб выбраць іншы тып базы даных.",
    "For more details check out the documentation." : "Для атрымання больш падрабязнай інфармацыі азнаёмцеся з дакументацыяй.",
    "Performance warning" : "Папярэджанне аб прадукцыйнасці",
    "You chose SQLite as database." : "Вы выбралі SQLite у якасці базы даных.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Калі вы выкарыстоўваеце кліенты для сінхранізацыі файлаў, выкарыстанне SQLite вельмі не рэкамендуецца.",
    "Database user" : "Карыстальнік базы даных",
    "Database password" : "Пароль базы даных",
    "Database name" : "Назва базы даных",
    "Database tablespace" : "Таблічная прастора базы даных",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Укажыце нумар порта разам з хостам (напрыклад, localhost:5432).",
    "Database host" : "Хост базы даных",
    "localhost" : "localhost",
    "Installing …" : "Усталяванне …",
    "Install" : "Усталяваць",
    "Need help?" : "Патрэбна дапамога?",
    "See the documentation" : "Глядзіце дакументацыю",
    "{name} version {version} and above" : "{name} версіі {version} і вышэй",
    "This browser is not supported" : "Гэты браўзер не падтрымліваецца",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш браўзер не падтрымліваецца. Абнавіце яго да новай версіі або да той, якая падтрымліваецца.",
    "Continue with this unsupported browser" : "Працягнуць выкарыстанне гэтага браўзера, які не падтрымліваецца",
    "Supported versions" : "Версіі, якія падтрымліваюцца",
    "Search {types} …" : "Пошук {types} …",
    "Choose {file}" : "Выбраць {file}",
    "Choose" : "Выбраць",
    "Copy to {target}" : "Капіяваць у {target}",
    "Copy" : "Капіяваць",
    "Move to {target}" : "Перамясціць у {target}",
    "Move" : "Перамясціць",
    "OK" : "OK",
    "read-only" : "толькі для чытання",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файлавы канфлікт","{count} файлавыя канфлікты","{count} файлавых канфліктаў","{count} файлавых канфліктаў"],
    "One file conflict" : "Адзін файлавы канфлікт",
    "New Files" : "Новыя файлы",
    "Already existing files" : "Ужо існуючыя файлы",
    "Which files do you want to keep?" : "Якія файлы вы хочаце захаваць?",
    "If you select both versions, the copied file will have a number added to its name." : "Калі бы выберыце абедзьве версіі, да назвы скапіяванага файла будзе дададзены нумар.",
    "Cancel" : "Скасаваць",
    "Continue" : "Працягнуць",
    "(all selected)" : "(усе выбраны)",
    "({count} selected)" : "(выбрана {count})",
    "Error loading file exists template" : "Памылка загрузкі шаблона",
    "Saving …" : "Захаванне …",
    "Groups" : "Групы",
    "Group list is empty" : "Спіс груп пусты",
    "seconds ago" : "с таму",
    "Connection to server lost" : "Злучэнне з серверам страчана",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Праблема з загрузкай старонкі, перазагрузка праз %n секунду","Праблема з загрузкай старонкі, перазагрузка праз %n секунды","Праблема з загрузкай старонкі, перазагрузка праз %n секунд","Праблема з загрузкай старонкі, перазагрузка праз %n секунд"],
    "Add to a project" : "Дадаць у праект",
    "Show details" : "Паказаць падрабязнасці",
    "Hide details" : "Схаваць падрабязнасці",
    "Rename project" : "Перайменаваць праект",
    "Failed to rename the project" : "Не ўдалося перайменаваць праект",
    "Failed to create a project" : "Не ўдалося стварыць праект",
    "Failed to add the item to the project" : "Не ўдалося дадаць элемент у праект",
    "New in" : "Новае ў",
    "View changelog" : "Праглядзець спіс змяненняў",
    "Close \"{dialogTitle}\" dialog" : "Закрыць дыялогавае акно \"{dialogTitle}\"",
    "Clipboard not available, please copy manually" : "Буфер абмену недаступны, скапіюйце ўручную",
    "Personal" : "Асабістыя",
    "Accounts" : "Уліковыя запісы",
    "Admin" : "Адміністратар",
    "Help" : "Даведка",
    "Access forbidden" : "Доступ забаронены",
    "You are not allowed to access this page." : "Вы не маеце доступу да гэтай старонкі.",
    "Back to %s" : "Назад да %s",
    "Page not found" : "Старонка не знойдзена",
    "The page could not be found on the server or you may not be allowed to view it." : "Старонка не знойдзена на серверы, або ў вас няма дазволу на яе прагляд.",
    "Too many requests" : "Занадта шмат запытаў",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "З вашай сеткі паступіла занадта шмат запытаў. Паўтарыце спробу пазней або звярніцеся да адміністратара, калі гэта памылка.",
    "Error" : "Памылка",
    "Internal Server Error" : "Унутраная памылка сервера",
    "The server was unable to complete your request." : "Сервер не змог выканаць ваш запыт.",
    "If this happens again, please send the technical details below to the server administrator." : "Калі гэта паўторыцца, адпраўце тэхнічныя падрабязнасці ніжэй адміністратару сервера.",
    "More details can be found in the server log." : "Больш падрабязную інфармацыю можна знайсці ў журнале сервера.",
    "For more details see the documentation ↗." : "Больш падрабязную інфармацыю глядзіце ў дакументацыі ↗.",
    "Technical details" : "Тэхнічныя падрабязнасці",
    "Remote Address: %s" : "Аддалены адрас: %s",
    "Request ID: %s" : "Ідэнтыфікатар запыту: %s",
    "Type: %s" : "Тып: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Паведамленне: %s",
    "File: %s" : "Файл: %s",
    "Line: %s" : "Радок: %s",
    "Trace" : "Трасіроўка",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Здаецца, вы спрабуеце пераўсталяваць Nextcloud. Аднак файл CAN_INSTALL адсутнічае ў вашым каталогу канфігурацыі. Каб працягнуць, стварыце файл CAN_INSTALL у папцы канфігурацыі.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не атрымалася выдаліць CAN_INSTALL з папкі канфігурацыі. Выдаліце ​​гэты файл уручную.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Для карэктнай працы гэтай праграмы патрабуецца JavaScript. {linkstart}Уключыце JavaScript{linkend} і перазагрузіце старонку.",
    "Go to %s" : "Перайсці да %s",
    "Previous" : "Папярэдняя",
    "Two-factor authentication" : "Двухфактарная аўтэнтыфікацыя",
    "Cancel login" : "Скасаваць уваход",
    "Access through untrusted domain" : "Доступ праз ненадзейны дамен",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Звярніцеся да адміністратара. Калі вы адміністратар, адрэдагуйце параметр \"trusted_domains\" у config/config.php, як у прыкладзе ў config.sample.php.",
    "App update required" : "Патрэбна абнавіць праграму",
    "%1$s will be updated to version %2$s" : "%1$s будзе абноўлена да версіі %2$s",
    "The following apps will be updated:" : "Будуць абноўлены наступныя праграмы:",
    "These incompatible apps will be disabled:" : "Гэтыя несумяшчальныя праграмы будуць адключаныя:",
    "The theme %s has been disabled." : "Тэма %s была адключана.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перад тым, як працягнуць, пераканайцеся, што ёсць рэзервовыя копіі базы даных, папкі канфігурацыі і папкі даных.",
    "Start update" : "Запусціць абнаўленне",
    "Detailed logs" : "Падрабязныя журналы",
    "Update needed" : "Неабходна абнаўленне",
    "Maintenance mode" : "Рэжым тэхнічнага абслугоўвання",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Звярніцеся да сістэмнага адміністратара, калі гэта паведамленне працягвае з'яўляцца або з'явілася нечакана.",
    "Error occurred while checking server setup" : "Падчас праверкі налад сервера адбылася памылка",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Больш падрабязную інфармацыю глядзіце ў {linkstart}дакументацыі ↗{linkend}",
    "unknown text" : "невядомы тэкст",
    "Hello world!" : "Hello world!",
    "sunny" : "сонечна",
    "Hello {name}, the weather is {weather}" : "Вітаем, {name}, на дварэ сёння {weather}",
    "Hello {name}" : "Вітаем, {name}",
    "new" : "новы",
    "_download %n file_::_download %n files_" : ["спампаваць %n файл","спампаваць %n файлы","спампаваць %n файлаў","спампаваць %n файлаў"],
    "Direct link copied to clipboard" : "Прамая спасылка скапіявана ў буфер абмену",
    "Searching …" : "Пошук …",
    "Logging in …" : "Уваход …",
    "Loading apps …" : "Загрузка праграм …",
    "Installing apps …" : "Усталяванне праграм …",
    "Loading your contacts …" : "Загрузка вашых кантактаў …",
    "Looking for {term} …" : "Пошук {term} …",
    "Search contacts …" : "Пошук кантактаў …",
    "Loading more results …" : "Загрузка дадатковых вынікаў …",
    "Search {types} …" : "Пошук {types} …",
    "Saving …" : "Захаванне …",
    "Very weak password" : "Вельмі слабы пароль",
    "Weak password" : "Слабы пароль",
    "So-so password" : "Абы-які пароль",
    "Good password" : "Файны пароль",
    "Strong password" : "Моцны пароль",
    "No action available" : "Няма даступных дзеянняў",
    "Non-existing tag #{tag}" : "Неіснуючы тэг #{tag}",
    "Restricted" : "Абмежавана",
    "Delete" : "Выдаліць",
    "Rename" : "Перайменаваць",
    "Collaborative tags" : "Супольныя тэгі",
    "No tags found" : "Тэгі не знойдзены",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог даных і файлы, верагодна, даступныя з Інтэрнэту, таму што файл .htaccess не працуе.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Каб даведацца, як правільна наладзіць сервер, глядзіце <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">дакументацыю</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Стварыць ўліковы запіс адміністратара</strong>",
    "New admin account name" : "Імя ўліковага запісу новага адміністратара",
    "New admin password" : "Пароль новага адіміністратара",
    "Show password" : "Паказаць пароль",
    "Toggle password visibility" : "Пераключыць бачнасць пароля",
    "Configure the database" : "Наладзіць базу даных",
    "Only %s is available." : "Даступна толькі %s.",
    "Database account" : "Уліковы запіс базы даных",
    "Installing …" : "Усталяванне …",
    "Please log in before granting %1$s access to your %2$s account." : "Увайдзіце ў сістэму, перш чым даць %1$s доступ да вашага ўліковага запісу %2$s.",
    "Currently logged in as %1$s (%2$s)." : "Вы ўвайшлі як %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Вы збіраецеся даць %1$s доступ да вашага ўліковага запісу %2$s."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
